@@ -6,9 +6,9 @@ import logging
 
 from RubyFormatter.fileFormatter import FileFormatter
 from RubyFormatter.cmdParser import CmdParser
-# import RubyFormatter.log
+import RubyFormatter.log
 
-__version__ = "0.2.1"
+__version__ = "0.2.7"
 
 logger = logging.getLogger('Formatter')
 
@@ -20,7 +20,7 @@ def run():
 
 
 def main():
-    print("Executing bootstrap version %s." % __version__)
+    print("Executing ruby-formatter version %s." % __version__)
     print("formatter is run")
     run()
 
